@@ -23,8 +23,6 @@
 #endif
 
 #include <gdk/gdkkeysyms.h>
-#include <gdk/gdk.h>
-#include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 
 #include <libxfce4util/libxfce4util.h>
