@@ -93,7 +93,7 @@ xfce_dialog_show_help_uri (GdkScreen *screen,
     {
       cmd = g_strdup_printf ("%s --launch WebBrowser '%s'", path, uri->str);
 
-      result = xfce_spawn_command_line_on_screen (screen, cmd, FALSE, TRUE, &error);
+      result = xfce_spawn_command_line (screen, cmd, FALSE, TRUE, TRUE, &error);
 
       g_free (path);
       g_free (cmd);
@@ -267,7 +267,7 @@ xfce_dialog_show_help_with_version (GtkWindow   *parent,
     primary = g_strdup (_("Do you want to read the manual online?"));
 
   dialog = xfce_message_dialog_new (parent,
-                                    NULL,
+                                    _("Read the manual"),
                                     "dialog-question",
                                     primary,
                                     _("You will be redirected to the documentation website "
