@@ -42,23 +42,16 @@
 #include <crt_externs.h> /* for _NSGetEnviron */
 #endif
 
-#include <gdk/gdk.h>
-
-#ifdef GDK_WINDOWING_X11
-#include <X11/Xatom.h>
-#include <gdk/gdkx.h>
-#else
-/* no x11, no sn */
-#undef HAVE_LIBSTARTUP_NOTIFICATION
-#endif
-
-#ifdef GDK_WINDOWING_WAYLAND
-#include <gdk/gdkwayland.h>
-#endif
-
+#ifdef ENABLE_X11
 #ifdef HAVE_LIBSTARTUP_NOTIFICATION
 #include <libsn/sn.h>
 #endif
+#include <X11/Xatom.h>
+#include <gdk/gdkx.h>
+#define WINDOWING_IS_X11() GDK_IS_X11_DISPLAY (gdk_display_get_default ())
+#else
+#define WINDOWING_IS_X11() FALSE
+#endif
 
 #include <glib/gstdio.h>
 #include <libxfce4util/libxfce4util.h>
@@ -280,7 +273,6 @@ xfce_spawn_process (GdkScreen    *screen,
                     gboolean      child_process)
 {
   gboolean            succeed;
-  gboolean            is_x11_display = FALSE;
   gchar             **cenvp;
   guint               n;
   guint               n_cenvp;
@@ -299,8 +291,7 @@ xfce_spawn_process (GdkScreen    *screen,
   g_return_val_if_fail ((flags & G_SPAWN_DO_NOT_REAP_CHILD) == 0, FALSE);
   g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-#ifdef GDK_WINDOWING_WAYLAND
-  if (GDK_IS_WAYLAND_DISPLAY (gdk_display_get_default ()))
+  if (!WINDOWING_IS_X11 ())
     {
       if (startup_notify == TRUE)
         {
@@ -309,7 +300,6 @@ xfce_spawn_process (GdkScreen    *screen,
           startup_notify = FALSE;
         }
     }
-#endif
 
   /* lookup the screen with the pointer */
   if (screen == NULL)
@@ -320,18 +310,15 @@ xfce_spawn_process (GdkScreen    *screen,
     envp = (gchar **) environ;
   for (n = 0; envp[n] != NULL; ++n);
   cenvp = g_new0 (gchar *, n + 3);
-#ifdef GDK_WINDOWING_X11
-  is_x11_display = GDK_IS_X11_DISPLAY (gdk_screen_get_display (screen));
-#endif
+
   for (n_cenvp = n = 0; envp[n] != NULL; ++n)
     {
       if (strncmp (envp[n], "DESKTOP_STARTUP_ID=", 19) != 0
-          && (!is_x11_display || strncmp (envp[n], "DISPLAY=", 8) != 0))
+          && (!WINDOWING_IS_X11 () || strncmp (envp[n], "DISPLAY=", 8) != 0))
         cenvp[n_cenvp++] = g_strdup (envp[n]);
     }
 
-#ifdef GDK_WINDOWING_X11
-  if (is_x11_display)
+  if (WINDOWING_IS_X11 ())
     {
       /* add the real display name for the screen */
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
@@ -341,7 +328,6 @@ G_GNUC_END_IGNORE_DEPRECATIONS
       cenvp[n_cenvp++] = g_strconcat ("DISPLAY=", display_name, NULL);
       g_free (display_name);
     }
-#endif
 
 #ifdef HAVE_LIBSTARTUP_NOTIFICATION
   /* initialize the sn launcher context */
